OCStage enum

Stages of an OpenConnect (Cisco AnyConnect-compatible) connection lifecycle.

Inheritance
Available extensions

Values

disconnected → const OCStage

Initial state.

preparing → const OCStage

Requesting VPN permission / preparing TUN interface.

connecting → const OCStage

TCP/TLS handshake with the gateway.

authenticating → const OCStage

Authenticating (username + password / certificate).

connected → const OCStage

Tunnel is established and traffic flows.

disconnecting → const OCStage

Graceful shutdown in progress.

error → const OCStage

An unrecoverable error occurred.

denied → const OCStage

VPN permission was denied by the user.

unknown → const OCStage

Stage reported by the native side is unrecognised.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OCStage>
A constant List of the values in this enum, in order of their declaration.