V2RayStage enum

Stages of a V2Ray/Xray connection lifecycle.

Inheritance
Available extensions

Values

disconnected → const V2RayStage

Initial state.

preparing → const V2RayStage

Requesting VPN permission / preparing TUN interface.

connecting → const V2RayStage

Connecting to the remote endpoint.

connected → const V2RayStage

Tunnel is up and traffic is flowing.

disconnecting → const V2RayStage

Graceful shutdown in progress.

error → const V2RayStage

An unrecoverable error occurred.

denied → const V2RayStage

VPN permission was denied by the user.

unknown → const V2RayStage

Stage reported by the native side is unrecognised.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<V2RayStage>
A constant List of the values in this enum, in order of their declaration.