V2RayStatus class

Status data emitted by the V2Ray/Xray engine.

Constructors

V2RayStatus({required String state, int bytesIn = 0, int bytesOut = 0, String? errorMessage})
const
V2RayStatus.empty()
factory
V2RayStatus.fromJson(Map<String, dynamic> json)
factory

Properties

bytesIn int
Bytes received since the tunnel was established.
final
bytesOut int
Bytes sent since the tunnel was established.
final
errorMessage String?
Error message, non-null only when state == "error".
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
Current connection state label (e.g. "connected", "disconnected").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited