V2RaySubProtocol enum
V2Ray sub-protocols supported by this engine.
Values
- vless → const V2RaySubProtocol
-
VLESS (recommended, no encryption overhead)
- vmess → const V2RaySubProtocol
-
VMess (legacy V2Ray protocol)
- trojan → const V2RaySubProtocol
-
Trojan (TLS-camouflage)
- shadowsocks → const V2RaySubProtocol
-
Shadowsocks
- unknown → const V2RaySubProtocol
-
Unknown / unrecognised sub-protocol
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
V2RaySubProtocol> - A constant List of the values in this enum, in order of their declaration.